google_api_partners v0.0.1 GoogleApi.Partners.V2.Api.Analytics View Source

API calls for all endpoints tagged Analytics.

Link to this section Summary

Functions

Lists analytics data for a user's associated company. Should only be called within the context of an authorized logged in user

Link to this section Functions

Link to this function partners_analytics_list(connection, opts \\ []) View Source
partners_analytics_list(Tesla.Env.client, keyword) ::
  {:ok, GoogleApi.Partners.V2.Model.ListAnalyticsResponse.t} |
  {:error, Tesla.Env.t}

Lists analytics data for a user's associated company. Should only be called within the context of an authorized logged in user.

Parameters

  • connection (GoogleApi.Partners.V2.Connection): Connection to server
  • opts (KeywordList): [optional] Optional parameters

    • :__/xgafv (String): V1 error format.
    • :callback (String): JSONP
    • :alt (String): Data format for response.
    • :access_token (String): OAuth access token.
    • :key (String): API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
    • :quota_user (String): Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
    • :pp (Boolean): Pretty-print response.
    • :bearer_token (String): OAuth bearer token.
    • :oauth_token (String): OAuth 2.0 token for the current user.
    • :upload_protocol (String): Upload protocol for media (e.g. "raw", "multipart").
    • :pretty_print (Boolean): Returns response with indentations and line breaks.
    • :upload_type (String): Legacy upload protocol for media (e.g. "media", "multipart").
    • :fields (String): Selector specifying which fields to include in a partial response.
    • :request_metadata/traffic_source/traffic_sub_id (String): Second level identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
    • :request_metadata/user_overrides/user_id (String): Logged-in user ID to impersonate instead of the user's ID.
    • :request_metadata/partners_session_id (String): Google Partners session ID.
    • :page_token (String): A token identifying a page of results that the server returns. Typically, this is the value of `ListAnalyticsResponse.next_page_token` returned from the previous call to ListAnalytics. Will be a date string in `YYYY-MM-DD` format representing the end date of the date range of results to return. If unspecified or set to "", default value is the current date.
    • :page_size (Integer): Requested page size. Server may return fewer analytics than requested. If unspecified or set to 0, default value is 30. Specifies the number of days in the date range when querying analytics. The `page_token` represents the end date of the date range and the start date is calculated using the `page_size` as the number of days BEFORE the end date. Must be a non-negative integer.
    • :request_metadata/traffic_source/traffic_source_id (String): Identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
    • :request_metadata/locale (String): Locale to use for the current request.
    • :request_metadata/user_overrides/ip_address (String): IP address to use instead of the user's geo-located IP address.
    • :request_metadata/experiment_ids (List[String]): Experiment IDs the current request belongs to.

Returns

{:ok, %GoogleApi.Partners.V2.Model.ListAnalyticsResponse{}} on success {:error, info} on failure