google_api_partners v0.1.0 GoogleApi.Partners.V2.Api.UserStates View Source
API calls for all endpoints tagged UserStates.
Link to this section Summary
Functions
Lists states for current user
Link to this section Functions
Link to this function
partners_user_states_list(connection, opts \\ [])
partners_user_states_list(Tesla.Env.client(), keyword()) :: {:ok, GoogleApi.Partners.V2.Model.ListUserStatesResponse.t()} | {:error, Tesla.Env.t()}
Lists states for current user.
Parameters
- connection (GoogleApi.Partners.V2.Connection): Connection to server
opts (KeywordList): [optional] Optional parameters
- :access_token (String.t): OAuth access token.
- :key (String.t): API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
- :upload_protocol (String.t): Upload protocol for media (e.g. "raw", "multipart").
- :quotaUser (String.t): Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
- :prettyPrint (boolean()): Returns response with indentations and line breaks.
- :fields (String.t): Selector specifying which fields to include in a partial response.
- :uploadType (String.t): Legacy upload protocol for media (e.g. "media", "multipart").
- :callback (String.t): JSONP
- :oauth_token (String.t): OAuth 2.0 token for the current user.
- :$.xgafv (String.t): V1 error format.
- :alt (String.t): Data format for response.
- :requestMetadata.userOverrides.userId (String.t): Logged-in user ID to impersonate instead of the user's ID.
- :requestMetadata.partnersSessionId (String.t): Google Partners session ID.
- :requestMetadata.trafficSource.trafficSourceId (String.t): Identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
- :requestMetadata.locale (String.t): Locale to use for the current request.
- :requestMetadata.userOverrides.ipAddress (String.t): IP address to use instead of the user's geo-located IP address.
- :requestMetadata.experimentIds ([String.t]): Experiment IDs the current request belongs to.
- :requestMetadata.trafficSource.trafficSubId (String.t): Second level identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
Returns
{:ok, %GoogleApi.Partners.V2.Model.ListUserStatesResponse{}} on success {:error, info} on failure