google_api_partners v0.0.1 GoogleApi.Partners.V2.Api.Users View Source
API calls for all endpoints tagged Users.
Link to this section Summary
Functions
Creates a user's company relation. Affiliates the user to a company
Deletes a user's company relation. Unaffiliaites the user from a company
Updates a user's profile. A user can only update their own profile and should only be called within the context of a logged in user
Link to this section Functions
partners_users_create_company_relation(Tesla.Env.client, String.t, keyword) :: {:ok, GoogleApi.Partners.V2.Model.CompanyRelation.t} | {:error, Tesla.Env.t}
Creates a user's company relation. Affiliates the user to a company.
Parameters
- connection (GoogleApi.Partners.V2.Connection): Connection to server
- user_id (String): The ID of the user. Can be set to <code>me</code> to mean the currently authenticated user.
opts (KeywordList): [optional] Optional parameters
- :__/xgafv (String): V1 error format.
- :callback (String): JSONP
- :alt (String): Data format for response.
- :access_token (String): OAuth access token.
- :key (String): API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
- :quota_user (String): Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
- :pp (Boolean): Pretty-print response.
- :bearer_token (String): OAuth bearer token.
- :oauth_token (String): OAuth 2.0 token for the current user.
- :upload_protocol (String): Upload protocol for media (e.g. "raw", "multipart").
- :pretty_print (Boolean): Returns response with indentations and line breaks.
- :upload_type (String): Legacy upload protocol for media (e.g. "media", "multipart").
- :fields (String): Selector specifying which fields to include in a partial response.
- :request_metadata/user_overrides/ip_address (String): IP address to use instead of the user's geo-located IP address.
- :request_metadata/experiment_ids (List[String]): Experiment IDs the current request belongs to.
- :request_metadata/traffic_source/traffic_sub_id (String): Second level identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
- :request_metadata/user_overrides/user_id (String): Logged-in user ID to impersonate instead of the user's ID.
- :request_metadata/partners_session_id (String): Google Partners session ID.
- :request_metadata/traffic_source/traffic_source_id (String): Identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
- :request_metadata/locale (String): Locale to use for the current request.
- :body (CompanyRelation):
Returns
{:ok, %GoogleApi.Partners.V2.Model.CompanyRelation{}} on success {:error, info} on failure
partners_users_delete_company_relation(Tesla.Env.client, String.t, keyword) :: {:ok, GoogleApi.Partners.V2.Model.Empty.t} | {:error, Tesla.Env.t}
Deletes a user's company relation. Unaffiliaites the user from a company.
Parameters
- connection (GoogleApi.Partners.V2.Connection): Connection to server
- user_id (String): The ID of the user. Can be set to <code>me</code> to mean the currently authenticated user.
opts (KeywordList): [optional] Optional parameters
- :__/xgafv (String): V1 error format.
- :callback (String): JSONP
- :alt (String): Data format for response.
- :access_token (String): OAuth access token.
- :key (String): API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
- :quota_user (String): Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
- :pp (Boolean): Pretty-print response.
- :bearer_token (String): OAuth bearer token.
- :oauth_token (String): OAuth 2.0 token for the current user.
- :upload_protocol (String): Upload protocol for media (e.g. "raw", "multipart").
- :pretty_print (Boolean): Returns response with indentations and line breaks.
- :upload_type (String): Legacy upload protocol for media (e.g. "media", "multipart").
- :fields (String): Selector specifying which fields to include in a partial response.
- :request_metadata/traffic_source/traffic_source_id (String): Identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
- :request_metadata/locale (String): Locale to use for the current request.
- :request_metadata/user_overrides/ip_address (String): IP address to use instead of the user's geo-located IP address.
- :request_metadata/experiment_ids (List[String]): Experiment IDs the current request belongs to.
- :request_metadata/traffic_source/traffic_sub_id (String): Second level identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
- :request_metadata/user_overrides/user_id (String): Logged-in user ID to impersonate instead of the user's ID.
- :request_metadata/partners_session_id (String): Google Partners session ID.
Returns
{:ok, %GoogleApi.Partners.V2.Model.Empty{}} on success {:error, info} on failure
partners_users_get(Tesla.Env.client, String.t, keyword) :: {:ok, GoogleApi.Partners.V2.Model.User.t} | {:error, Tesla.Env.t}
Gets a user.
Parameters
- connection (GoogleApi.Partners.V2.Connection): Connection to server
- user_id (String): Identifier of the user. Can be set to <code>me</code> to mean the currently authenticated user.
opts (KeywordList): [optional] Optional parameters
- :__/xgafv (String): V1 error format.
- :callback (String): JSONP
- :alt (String): Data format for response.
- :access_token (String): OAuth access token.
- :key (String): API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
- :quota_user (String): Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
- :pp (Boolean): Pretty-print response.
- :bearer_token (String): OAuth bearer token.
- :oauth_token (String): OAuth 2.0 token for the current user.
- :upload_protocol (String): Upload protocol for media (e.g. "raw", "multipart").
- :pretty_print (Boolean): Returns response with indentations and line breaks.
- :upload_type (String): Legacy upload protocol for media (e.g. "media", "multipart").
- :fields (String): Selector specifying which fields to include in a partial response.
- :request_metadata/partners_session_id (String): Google Partners session ID.
- :request_metadata/user_overrides/user_id (String): Logged-in user ID to impersonate instead of the user's ID.
- :user_view (String): Specifies what parts of the user information to return.
- :request_metadata/traffic_source/traffic_source_id (String): Identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
- :request_metadata/locale (String): Locale to use for the current request.
- :request_metadata/user_overrides/ip_address (String): IP address to use instead of the user's geo-located IP address.
- :request_metadata/experiment_ids (List[String]): Experiment IDs the current request belongs to.
- :request_metadata/traffic_source/traffic_sub_id (String): Second level identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
Returns
{:ok, %GoogleApi.Partners.V2.Model.User{}} on success {:error, info} on failure
partners_users_update_profile(Tesla.Env.client, keyword) :: {:ok, GoogleApi.Partners.V2.Model.UserProfile.t} | {:error, Tesla.Env.t}
Updates a user's profile. A user can only update their own profile and should only be called within the context of a logged in user.
Parameters
- connection (GoogleApi.Partners.V2.Connection): Connection to server
opts (KeywordList): [optional] Optional parameters
- :__/xgafv (String): V1 error format.
- :callback (String): JSONP
- :alt (String): Data format for response.
- :access_token (String): OAuth access token.
- :key (String): API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
- :quota_user (String): Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
- :pp (Boolean): Pretty-print response.
- :bearer_token (String): OAuth bearer token.
- :oauth_token (String): OAuth 2.0 token for the current user.
- :upload_protocol (String): Upload protocol for media (e.g. "raw", "multipart").
- :pretty_print (Boolean): Returns response with indentations and line breaks.
- :upload_type (String): Legacy upload protocol for media (e.g. "media", "multipart").
- :fields (String): Selector specifying which fields to include in a partial response.
- :request_metadata/partners_session_id (String): Google Partners session ID.
- :request_metadata/user_overrides/user_id (String): Logged-in user ID to impersonate instead of the user's ID.
- :request_metadata/traffic_source/traffic_source_id (String): Identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
- :request_metadata/locale (String): Locale to use for the current request.
- :request_metadata/user_overrides/ip_address (String): IP address to use instead of the user's geo-located IP address.
- :request_metadata/experiment_ids (List[String]): Experiment IDs the current request belongs to.
- :request_metadata/traffic_source/traffic_sub_id (String): Second level identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
- :body (UserProfile):
Returns
{:ok, %GoogleApi.Partners.V2.Model.UserProfile{}} on success {:error, info} on failure