google_api_partners v0.0.1 GoogleApi.Partners.V2.Api.V2 View Source

API calls for all endpoints tagged V2.

Link to this section Summary

Functions

Gets Partners Status of the logged in user's agency. Should only be called if the logged in user is the admin of the agency

Update company. Should only be called within the context of an authorized logged in user

Link to this section Functions

Link to this function partners_get_partnersstatus(connection, opts \\ []) View Source
partners_get_partnersstatus(Tesla.Env.client, keyword) ::
  {:ok, GoogleApi.Partners.V2.Model.GetPartnersStatusResponse.t} |
  {:error, Tesla.Env.t}

Gets Partners Status of the logged in user's agency. Should only be called if the logged in user is the admin of the agency.

Parameters

  • connection (GoogleApi.Partners.V2.Connection): Connection to server
  • opts (KeywordList): [optional] Optional parameters

    • :__/xgafv (String): V1 error format.
    • :callback (String): JSONP
    • :alt (String): Data format for response.
    • :access_token (String): OAuth access token.
    • :key (String): API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
    • :quota_user (String): Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
    • :pp (Boolean): Pretty-print response.
    • :bearer_token (String): OAuth bearer token.
    • :oauth_token (String): OAuth 2.0 token for the current user.
    • :upload_protocol (String): Upload protocol for media (e.g. "raw", "multipart").
    • :pretty_print (Boolean): Returns response with indentations and line breaks.
    • :upload_type (String): Legacy upload protocol for media (e.g. "media", "multipart").
    • :fields (String): Selector specifying which fields to include in a partial response.
    • :request_metadata/traffic_source/traffic_sub_id (String): Second level identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
    • :request_metadata/partners_session_id (String): Google Partners session ID.
    • :request_metadata/user_overrides/user_id (String): Logged-in user ID to impersonate instead of the user's ID.
    • :request_metadata/traffic_source/traffic_source_id (String): Identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
    • :request_metadata/locale (String): Locale to use for the current request.
    • :request_metadata/user_overrides/ip_address (String): IP address to use instead of the user's geo-located IP address.
    • :request_metadata/experiment_ids (List[String]): Experiment IDs the current request belongs to.

Returns

{:ok, %GoogleApi.Partners.V2.Model.GetPartnersStatusResponse{}} on success {:error, info} on failure

Link to this function partners_update_companies(connection, opts \\ []) View Source
partners_update_companies(Tesla.Env.client, keyword) ::
  {:ok, GoogleApi.Partners.V2.Model.Company.t} |
  {:error, Tesla.Env.t}

Update company. Should only be called within the context of an authorized logged in user.

Parameters

  • connection (GoogleApi.Partners.V2.Connection): Connection to server
  • opts (KeywordList): [optional] Optional parameters

    • :__/xgafv (String): V1 error format.
    • :callback (String): JSONP
    • :alt (String): Data format for response.
    • :access_token (String): OAuth access token.
    • :key (String): API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
    • :quota_user (String): Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
    • :pp (Boolean): Pretty-print response.
    • :bearer_token (String): OAuth bearer token.
    • :oauth_token (String): OAuth 2.0 token for the current user.
    • :upload_protocol (String): Upload protocol for media (e.g. "raw", "multipart").
    • :pretty_print (Boolean): Returns response with indentations and line breaks.
    • :upload_type (String): Legacy upload protocol for media (e.g. "media", "multipart").
    • :fields (String): Selector specifying which fields to include in a partial response.
    • :request_metadata/traffic_source/traffic_sub_id (String): Second level identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
    • :request_metadata/user_overrides/user_id (String): Logged-in user ID to impersonate instead of the user's ID.
    • :request_metadata/partners_session_id (String): Google Partners session ID.
    • :request_metadata/traffic_source/traffic_source_id (String): Identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
    • :request_metadata/locale (String): Locale to use for the current request.
    • :request_metadata/user_overrides/ip_address (String): IP address to use instead of the user's geo-located IP address.
    • :update_mask (String): Standard field mask for the set of fields to be updated. Required with at least 1 value in FieldMask's paths.
    • :request_metadata/experiment_ids (List[String]): Experiment IDs the current request belongs to.
    • :body (Company):

Returns

{:ok, %GoogleApi.Partners.V2.Model.Company{}} on success {:error, info} on failure

Link to this function partners_update_leads(connection, opts \\ []) View Source
partners_update_leads(Tesla.Env.client, keyword) ::
  {:ok, GoogleApi.Partners.V2.Model.Lead.t} |
  {:error, Tesla.Env.t}

Updates the specified lead.

Parameters

  • connection (GoogleApi.Partners.V2.Connection): Connection to server
  • opts (KeywordList): [optional] Optional parameters

    • :__/xgafv (String): V1 error format.
    • :callback (String): JSONP
    • :alt (String): Data format for response.
    • :access_token (String): OAuth access token.
    • :key (String): API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
    • :quota_user (String): Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
    • :pp (Boolean): Pretty-print response.
    • :bearer_token (String): OAuth bearer token.
    • :oauth_token (String): OAuth 2.0 token for the current user.
    • :upload_protocol (String): Upload protocol for media (e.g. "raw", "multipart").
    • :pretty_print (Boolean): Returns response with indentations and line breaks.
    • :upload_type (String): Legacy upload protocol for media (e.g. "media", "multipart").
    • :fields (String): Selector specifying which fields to include in a partial response.
    • :request_metadata/traffic_source/traffic_source_id (String): Identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
    • :request_metadata/locale (String): Locale to use for the current request.
    • :request_metadata/user_overrides/ip_address (String): IP address to use instead of the user's geo-located IP address.
    • :update_mask (String): Standard field mask for the set of fields to be updated. Required with at least 1 value in FieldMask's paths. Only `state` and `adwords_customer_id` are currently supported.
    • :request_metadata/experiment_ids (List[String]): Experiment IDs the current request belongs to.
    • :request_metadata/traffic_source/traffic_sub_id (String): Second level identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
    • :request_metadata/user_overrides/user_id (String): Logged-in user ID to impersonate instead of the user's ID.
    • :request_metadata/partners_session_id (String): Google Partners session ID.
    • :body (Lead):

Returns

{:ok, %GoogleApi.Partners.V2.Model.Lead{}} on success {:error, info} on failure