google_api_partners v0.1.0 GoogleApi.Partners.V2.Model.AvailableOffer View Source
Available Offers to be distributed.
Attributes
- available (integer()): The number of codes for this offer that are available for distribution. Defaults to:
null. - countryOfferInfos ([CountryOfferInfo]): Offer info by country. Defaults to:
null. - description (String.t): Description of the offer. Defaults to:
null. - id (String.t): ID of this offer. Defaults to:
null. - maxAccountAge (integer()): The maximum age of an account [in days] to be eligible. Defaults to:
null. - name (String.t): Name of the offer. Defaults to:
null. offerLevel (String.t): Level of this offer. Defaults to:
null.- Enum - one of [OFFER_LEVEL_UNSPECIFIED, OFFER_LEVEL_DENY_PROBLEM, OFFER_LEVEL_DENY_CONTRACT, OFFER_LEVEL_MANUAL, OFFER_LEVEL_LIMIT_0, OFFER_LEVEL_LIMIT_5, OFFER_LEVEL_LIMIT_15, OFFER_LEVEL_LIMIT_50]
offerType (String.t): Type of offer. Defaults to:
null.- Enum - one of [OFFER_TYPE_UNSPECIFIED, OFFER_TYPE_SPEND_X_GET_Y, OFFER_TYPE_VIDEO, OFFER_TYPE_SPEND_MATCH]
- qualifiedCustomer ([OfferCustomer]): Customers who qualify for this offer. Defaults to:
null. - qualifiedCustomersComplete (boolean()): Whether or not the list of qualified customers is definitely complete. Defaults to:
null. - showSpecialOfferCopy (boolean()): Should special text be shown on the offers page. Defaults to:
null. - terms (String.t): Terms of the offer. Defaults to:
null.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields
Link to this section Types
Link to this type
t()
t() :: %GoogleApi.Partners.V2.Model.AvailableOffer{
available: any(),
countryOfferInfos: [GoogleApi.Partners.V2.Model.CountryOfferInfo.t()],
description: any(),
id: any(),
maxAccountAge: any(),
name: any(),
offerLevel: any(),
offerType: any(),
qualifiedCustomer: [GoogleApi.Partners.V2.Model.OfferCustomer.t()],
qualifiedCustomersComplete: any(),
showSpecialOfferCopy: any(),
terms: any()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.