google_api_partners v0.1.0 GoogleApi.Partners.V2.Model.CompanyRelation View Source
A CompanyRelation resource representing information about a user's affiliation and standing with a company in Partners.
Attributes
- address (String.t): The primary address for this company. Defaults to:
null. badgeTier (String.t): Whether the company is a Partner. Defaults to:
null.- Enum - one of [BADGE_TIER_NONE, BADGE_TIER_REGULAR, BADGE_TIER_PREMIER]
- companyAdmin (boolean()): Indicates if the user is an admin for this company. Defaults to:
null. - companyId (String.t): The ID of the company. There may be no id if this is a pending company.5 Defaults to:
null. - creationTime (DateTime.t): The timestamp of when affiliation was requested. @OutputOnly Defaults to:
null. - internalCompanyId (String.t): The internal company ID. Only available for a whitelisted set of api clients. Defaults to:
null. - isPending (boolean()): The flag that indicates if the company is pending verification. Defaults to:
null. - logoUrl (String.t): A URL to a profile photo, e.g. a G+ profile photo. Defaults to:
null. - managerAccount (String.t): The AdWords manager account # associated this company. Defaults to:
null. - name (String.t): The name (in the company's primary language) for the company. Defaults to:
null. - phoneNumber (String.t): The phone number for the company's primary address. Defaults to:
null. - primaryAddress (Location): The primary location of the company. Defaults to:
null. - primaryCountryCode (String.t): The primary country code of the company. Defaults to:
null. - primaryLanguageCode (String.t): The primary language code of the company. Defaults to:
null. - resolvedTimestamp (DateTime.t): The timestamp when the user was approved. @OutputOnly Defaults to:
null. segment ([String.t]): The segment the company is classified as. Defaults to:
null.- Enum - one of
- specializationStatus ([SpecializationStatus]): The list of Google Partners specialization statuses for the company. Defaults to:
null. state (String.t): The state of relationship, in terms of approvals. Defaults to:
null.- Enum - one of [USER_COMPANY_REATION_STATE_NONE_SPECIFIED, USER_COMPANY_RELATION_STATE_AWAIT_EMAIL, USER_COMPANY_RELATION_STATE_AWAIT_ADMIN, USER_COMPANY_RELATION_STATE_APPROVED]
- website (String.t): The website URL for this company. Defaults to:
null.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields
Link to this section Types
Link to this type
t()
t() :: %GoogleApi.Partners.V2.Model.CompanyRelation{
address: any(),
badgeTier: any(),
companyAdmin: any(),
companyId: any(),
creationTime: DateTime.t(),
internalCompanyId: any(),
isPending: any(),
logoUrl: any(),
managerAccount: any(),
name: any(),
phoneNumber: any(),
primaryAddress: GoogleApi.Partners.V2.Model.Location.t(),
primaryCountryCode: any(),
primaryLanguageCode: any(),
resolvedTimestamp: DateTime.t(),
segment: [any()],
specializationStatus: [GoogleApi.Partners.V2.Model.SpecializationStatus.t()],
state: any(),
website: any()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.