google_api_partners v0.1.0 GoogleApi.Partners.V2.Model.ExamStatus View Source
A user's information on a specific exam.
Attributes
examType (String.t): The type of the exam. Defaults to:
null.- Enum - one of [CERTIFICATION_EXAM_TYPE_UNSPECIFIED, CET_ADWORDS_FUNDAMENTALS, CET_ADWORDS_ADVANCED_SEARCH, CET_ADWORDS_ADVANCED_DISPLAY, CET_VIDEO_ADS, CET_DOUBLECLICK, CET_ANALYTICS, CET_SHOPPING, CET_MOBILE, CET_DIGITAL_SALES, CET_MOBILE_SITES]
- expiration (DateTime.t): Date this exam is due to expire. Defaults to:
null. - lastPassed (DateTime.t): The date the user last passed this exam. Defaults to:
null. - passed (boolean()): Whether this exam has been passed and not expired. Defaults to:
null. - taken (DateTime.t): The date the user last taken this exam. Defaults to:
null. - warning (boolean()): Whether this exam is in the state of warning. Defaults to:
null.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields
Link to this section Types
Link to this type
t()
t() :: %GoogleApi.Partners.V2.Model.ExamStatus{
examType: any(),
expiration: DateTime.t(),
lastPassed: DateTime.t(),
passed: any(),
taken: DateTime.t(),
warning: any()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.