google_api_partners v0.1.0 GoogleApi.Partners.V2.Model.Lead View Source
A lead resource that represents an advertiser contact for a `Company`. These are usually generated via Google Partner Search (the advertiser portal).
Attributes
- adwordsCustomerId (String.t): The AdWords Customer ID of the lead. Defaults to:
null. - comments (String.t): Comments lead source gave. Defaults to:
null. - createTime (DateTime.t): Timestamp of when this lead was created. Defaults to:
null. - email (String.t): Email address of lead source. Defaults to:
null. - familyName (String.t): Last name of lead source. Defaults to:
null. - givenName (String.t): First name of lead source. Defaults to:
null. gpsMotivations ([String.t]): List of reasons for using Google Partner Search and creating a lead. Defaults to:
null.- Enum - one of
- id (String.t): ID of the lead. Defaults to:
null. - languageCode (String.t): Language code of the lead's language preference, as defined by <a href="https://tools.ietf.org/html/bcp47">BCP 47</a> (IETF BCP 47, "Tags for Identifying Languages"). Defaults to:
null. - marketingOptIn (boolean()): Whether or not the lead signed up for marketing emails Defaults to:
null. - minMonthlyBudget (Money): The minimum monthly budget lead source is willing to spend. Defaults to:
null. - phoneNumber (String.t): Phone number of lead source. Defaults to:
null. state (String.t): The lead's state in relation to the company. Defaults to:
null.- Enum - one of [LEAD_STATE_UNSPECIFIED, LEAD, CONTACTED, CLIENT, OTHER]
type (String.t): Type of lead. Defaults to:
null.- Enum - one of [LEAD_TYPE_UNSPECIFIED, LT_GPS]
- websiteUrl (String.t): Website URL of lead source. Defaults to:
null.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields
Link to this section Types
Link to this type
t()
t() :: %GoogleApi.Partners.V2.Model.Lead{
adwordsCustomerId: any(),
comments: any(),
createTime: DateTime.t(),
email: any(),
familyName: any(),
givenName: any(),
gpsMotivations: [any()],
id: any(),
languageCode: any(),
marketingOptIn: any(),
minMonthlyBudget: GoogleApi.Partners.V2.Model.Money.t(),
phoneNumber: any(),
state: any(),
type: any(),
websiteUrl: any()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.