google_api_partners v0.1.0 GoogleApi.Partners.V2.Model.ListOffersHistoryResponse View Source
Response for ListOfferHistory.
Attributes
- canShowEntireCompany (boolean()): True if the user has the option to show entire company history. Defaults to:
null. - nextPageToken (String.t): Supply this token in a ListOffersHistoryRequest to retrieve the next page. Defaults to:
null. - offers ([HistoricalOffer]): Historical offers meeting request. Defaults to:
null. - responseMetadata (ResponseMetadata): Current response metadata. Defaults to:
null. - showingEntireCompany (boolean()): True if this response is showing entire company history. Defaults to:
null. - totalResults (integer()): Number of results across all pages. Defaults to:
null.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields
Link to this section Types
Link to this type
t()
t() :: %GoogleApi.Partners.V2.Model.ListOffersHistoryResponse{
canShowEntireCompany: any(),
nextPageToken: any(),
offers: [GoogleApi.Partners.V2.Model.HistoricalOffer.t()],
responseMetadata: GoogleApi.Partners.V2.Model.ResponseMetadata.t(),
showingEntireCompany: any(),
totalResults: any()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.