google_api_partners v0.0.1 GoogleApi.Partners.V2.Model.Location View Source

A location with address and geographic coordinates. May optionally contain a detailed (multi-field) version of the address.

Attributes

  • address (String): The single string version of the address. Defaults to: null.
  • addressLine (List[String]): The following address lines represent the most specific part of any address. Defaults to: null.
  • administrativeArea (String): Top-level administrative subdivision of this country. Defaults to: null.
  • dependentLocality (String): Dependent locality or sublocality. Used for UK dependent localities, or neighborhoods or boroughs in other locations. Defaults to: null.
  • languageCode (String): Language code of the address. Should be in BCP 47 format. Defaults to: null.
  • latLng (LatLng): The latitude and longitude of the location, in degrees. Defaults to: null.
  • locality (String): Generally refers to the city/town portion of an address. Defaults to: null.
  • postalCode (String): Values are frequently alphanumeric. Defaults to: null.
  • regionCode (String): CLDR (Common Locale Data Repository) region code . Defaults to: null.
  • sortingCode (String): Use of this code is very country-specific, but will refer to a secondary classification code for sorting mail. Defaults to: null.