google_api_partners v0.0.1 GoogleApi.Partners.V2.Model.PublicProfile View Source

Basic information from a public profile.

Attributes

  • displayImageUrl (String): The URL to the main display image of the public profile. Being deprecated. Defaults to: null.
  • displayName (String): The display name of the public profile. Defaults to: null.
  • id (String): The ID which can be used to retrieve more details about the public profile. Defaults to: null.
  • profileImage (String): The URL to the main profile image of the public profile. Defaults to: null.
  • url (String): The URL of the public profile. Defaults to: null.