google_api_partners v0.1.0 GoogleApi.Partners.V2.Model.UserProfile View Source
The profile information of a Partners user.
Attributes
- address (Location): The user's mailing address, contains multiple fields. Defaults to:
null. - adwordsManagerAccount (String.t): If the user has edit access to multiple accounts, the user can choose the preferred account and it is used when a personal account is needed. Can be empty. Defaults to:
null. - channels ([String.t]): A list of ids representing which channels the user selected they were in. Defaults to:
null. - emailAddress (String.t): The email address the user has selected on the Partners site as primary. Defaults to:
null. - emailOptIns (OptIns): The list of opt-ins for the user, related to communication preferences. Defaults to:
null. - familyName (String.t): The user's family name. Defaults to:
null. - givenName (String.t): The user's given name. Defaults to:
null. - industries ([String.t]): A list of ids representing which industries the user selected. Defaults to:
null. - jobFunctions ([String.t]): A list of ids represnting which job categories the user selected. Defaults to:
null. - languages ([String.t]): The list of languages this user understands. Defaults to:
null. - markets ([String.t]): A list of ids representing which markets the user was interested in. Defaults to:
null. - migrateToAfa (boolean()): Whether or not to migrate the user's exam data to Academy for Ads. Defaults to:
null. - phoneNumber (String.t): The user's phone number. Defaults to:
null. - primaryCountryCode (String.t): The user's primary country, an ISO 2-character code. Defaults to:
null. - profilePublic (boolean()): Whether the user's public profile is visible to anyone with the URL. Defaults to:
null.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields
Link to this section Types
Link to this type
t()
t() :: %GoogleApi.Partners.V2.Model.UserProfile{
address: GoogleApi.Partners.V2.Model.Location.t(),
adwordsManagerAccount: any(),
channels: [any()],
emailAddress: any(),
emailOptIns: GoogleApi.Partners.V2.Model.OptIns.t(),
familyName: any(),
givenName: any(),
industries: [any()],
jobFunctions: [any()],
languages: [any()],
markets: [any()],
migrateToAfa: any(),
phoneNumber: any(),
primaryCountryCode: any(),
profilePublic: any()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.