google_api_partners v0.0.1 GoogleApi.Partners.V2.Api.UserStates View Source
API calls for all endpoints tagged UserStates.
Link to this section Summary
Functions
Lists states for current user
Link to this section Functions
Link to this function
partners_user_states_list(connection, opts \\ [])
partners_user_states_list(Tesla.Env.client, keyword) :: {:ok, GoogleApi.Partners.V2.Model.ListUserStatesResponse.t} | {:error, Tesla.Env.t}
Lists states for current user.
Parameters
- connection (GoogleApi.Partners.V2.Connection): Connection to server
opts (KeywordList): [optional] Optional parameters
- :__/xgafv (String): V1 error format.
- :callback (String): JSONP
- :alt (String): Data format for response.
- :access_token (String): OAuth access token.
- :key (String): API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
- :quota_user (String): Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
- :pp (Boolean): Pretty-print response.
- :bearer_token (String): OAuth bearer token.
- :oauth_token (String): OAuth 2.0 token for the current user.
- :upload_protocol (String): Upload protocol for media (e.g. "raw", "multipart").
- :pretty_print (Boolean): Returns response with indentations and line breaks.
- :upload_type (String): Legacy upload protocol for media (e.g. "media", "multipart").
- :fields (String): Selector specifying which fields to include in a partial response.
- :request_metadata/traffic_source/traffic_source_id (String): Identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
- :request_metadata/locale (String): Locale to use for the current request.
- :request_metadata/user_overrides/ip_address (String): IP address to use instead of the user's geo-located IP address.
- :request_metadata/experiment_ids (List[String]): Experiment IDs the current request belongs to.
- :request_metadata/traffic_source/traffic_sub_id (String): Second level identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us.
- :request_metadata/user_overrides/user_id (String): Logged-in user ID to impersonate instead of the user's ID.
- :request_metadata/partners_session_id (String): Google Partners session ID.
Returns
{:ok, %GoogleApi.Partners.V2.Model.ListUserStatesResponse{}} on success {:error, info} on failure