google_api_partners v0.0.1 GoogleApi.Partners.V2.Model.ExamToken View Source
A token that allows a user to take an exam.
Attributes
- examId (String): The id of the exam the token is for. Defaults to:
null. examType (String): The type of the exam the token belongs to. Defaults to:
null.- Enum - one of [CERTIFICATION_EXAM_TYPE_UNSPECIFIED, CET_ADWORDS_FUNDAMENTALS, CET_ADWORDS_ADVANCED_SEARCH, CET_ADWORDS_ADVANCED_DISPLAY, CET_VIDEO_ADS, CET_DOUBLECLICK, CET_ANALYTICS, CET_SHOPPING, CET_MOBILE, CET_DIGITAL_SALES, CET_MOBILE_SITES]
- token (String): The token, only present if the user has access to the exam. Defaults to:
null.