google_api_partners v0.0.1 GoogleApi.Partners.V2.Model.ListOffersHistoryResponse View Source

Response for ListOfferHistory.

Attributes

  • canShowEntireCompany (Boolean): True if the user has the option to show entire company history. Defaults to: null.
  • nextPageToken (String): Supply this token in a ListOffersHistoryRequest to retrieve the next page. Defaults to: null.
  • offers (List[HistoricalOffer]): Historical offers meeting request. Defaults to: null.
  • responseMetadata (ResponseMetadata): Current response metadata. Defaults to: null.
  • showingEntireCompany (Boolean): True if this response is showing entire company history. Defaults to: null.
  • totalResults (Integer): Number of results across all pages. Defaults to: null.