google_api_partners v0.0.1 GoogleApi.Partners.V2.Model.LocalizedCompanyInfo View Source
The localized company information.
Attributes
- countryCodes (List[String]): List of country codes for the localized company info. Defaults to:
null. - displayName (String): Localized display name. Defaults to:
null. - languageCode (String): Language code of the localized company info, as defined by <a href="https://tools.ietf.org/html/bcp47">BCP 47</a> (IETF BCP 47, "Tags for Identifying Languages"). Defaults to:
null. - overview (String): Localized brief description that the company uses to advertise themselves. Defaults to:
null.