google_api_partners v0.0.1 GoogleApi.Partners.V2.Model.TrafficSource View Source
Source of traffic for the current request.
Attributes
- trafficSourceId (String): Identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us. Defaults to:
null. - trafficSubId (String): Second level identifier to indicate where the traffic comes from. An identifier has multiple letters created by a team which redirected the traffic to us. Defaults to:
null.