google_api_partners v0.0.1 GoogleApi.Partners.V2.Model.UserProfile View Source

The profile information of a Partners user.

Attributes

  • address (Location): The user's mailing address, contains multiple fields. Defaults to: null.
  • adwordsManagerAccount (String): If the user has edit access to multiple accounts, the user can choose the preferred account and it is used when a personal account is needed. Can be empty. Defaults to: null.
  • channels (List[String]): A list of ids representing which channels the user selected they were in. Defaults to: null.
  • emailAddress (String): The email address the user has selected on the Partners site as primary. Defaults to: null.
  • emailOptIns (OptIns): The list of opt-ins for the user, related to communication preferences. Defaults to: null.
  • familyName (String): The user's family name. Defaults to: null.
  • givenName (String): The user's given name. Defaults to: null.
  • industries (List[String]): A list of ids representing which industries the user selected. Defaults to: null.
  • jobFunctions (List[String]): A list of ids represnting which job categories the user selected. Defaults to: null.
  • languages (List[String]): The list of languages this user understands. Defaults to: null.
  • markets (List[String]): A list of ids representing which markets the user was interested in. Defaults to: null.
  • phoneNumber (String): The user's phone number. Defaults to: null.
  • primaryCountryCode (String): The user's primary country, an ISO 2-character code. Defaults to: null.
  • profilePublic (Boolean): Whether the user's public profile is visible to anyone with the URL. Defaults to: null.